package cn.com.ctop.kuaishou.modules.batch.mapper;

import cn.com.ctop.kuaishou.modules.batch.entity.KuaishouSupplyChain;
import com.alibaba.fastjson.JSONObject;
import org.apache.ibatis.annotations.Param;

import java.util.List;

public interface ZhiShuiSupplyChainMapper {
    List<JSONObject> getCookie();

    void replaceRuixuanSupplyChains(@Param(value = "adds") List<KuaishouSupplyChain> ruixuanSupplyChains);

    void replaceMgsSupplyChains(@Param(value = "adds") List<KuaishouSupplyChain> mgsSupplyChains);

    void replaceRocketSupplyChains(@Param(value = "adds") List<KuaishouSupplyChain> rocketSupplyChains);

    void replaceYufuSupplyChains(@Param(value = "adds") List<KuaishouSupplyChain> yufuSupplyChains);

    void replaceYuXiuSupplyChains(@Param("adds") List<KuaishouSupplyChain> yuxiuSupplyChains);

    void replaceZhiShuiSupplyChains(@Param("adds") List<KuaishouSupplyChain> zhiShuiSupplyChains);
}
